#[non_exhaustive]pub enum Event<'a> {
Send {
mime_type: String,
fd: BorrowedFd<'a>,
},
Cancelled,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Send
send the data
Request for data from the client. Send the data as the specified MIME type over the passed file descriptor, then close it.
Cancelled
selection was cancelled
This data source is no longer valid. The data source has been replaced by another data source.
The client should clean up and destroy this data source.
Implementations